@@ -192,6 +192,10 @@ class QmakeBuilder(Builder):
 
         args.append(self.qmake_quote(project.get_distinfo_dir(target_dir)))
 
+        pro_lines.append('distinfo.depends = install_subtargets {}'.format(
+                ' '.join(
+                        ['install_' + installable.name
+                                for installable in project.installables])))
         pro_lines.append('distinfo.extra = {}'.format(' '.join(args)))
         pro_lines.append(
                 'distinfo.path = {}'.format(self.qmake_quote(target_dir)))
@@ -407,7 +411,8 @@ macx {
         # TODO: is this still necessary for Python v3.8?
         if not buildable.static:
             pro_lines.extend(['win32 {',
-                    '    LIBS += -L{}'.format(project.py_pylib_dir),
+                    '    LIBS += -L{}'.format(
+                            self.qmake_quote(project.py_pylib_dir)),
                     '}'])
 
         # Add any installables from the buildable.
